## Description

<!--- A summary of the changes that this PR introduces. Provide a relevant motivation and context about this PR or link an issue that provides it. -->

Closes #

Related #

## Areas of interest for the reviewer

<!--- Which parts of the code should the code reviewer check?  -->

## Checklist

<!--- Check items that you fulfilled, strikeout the ones that do not apply and write why  -->

- [ ] My code follows the [style guidelines] as defined by IRNAS.
- [ ] I have performed a self-review of my code.
- [ ] My changes generate no new warnings.
- [ ] I added/updated source code documentation for all newly added or changed
      functions.
- [ ] I updated all customer-facing technical documentation.

Example strikeout: - [x] ~~I updated all customer-facing technical documentation.~~ - This PR introduced only internal facing changes.

## After-review steps

<!--- Delete section or select one option -->

- Reviewer can merge and delete the branch.
- I will merge PR by myself.

[style guidelines]:
  https://github.com/IRNAS/irnas-guidelines-docs/blob/main/docs/developer_guidelines.md
